==> hermes-6.0.0.11.tar.gz: hermes-6.0.0.11/app/models/hermes/concerns/eligibility_concern.rb <==
# frozen_string_literal: true

# app/hermes/models/concerns/status.rb
# app/controllers/concerns/test_concern.rb

module Hermes
  module Concerns
    # Handles statuses relationships
    module EligibilityConcern
      extend ActiveSupport::Concern

      included do
        field :eligibility_query_base, type: String
        field :eligibility_query_department, type: String
        field :eligibility_query_seeked, type: String
        field :eligibility_query_bordering, type: String
        field :eligibility_query_seeked_bordering, type: String
        field :eligibility_query_other_from_department, type: String


        ELIGIBILITY_TYPES = %w[
          department
          seeked
          bordering
          seeked_bordering
          other_from_department
        ].freeze

        def self.eligibility_types
          ELIGIBILITY_TYPES
        end 

        def blank_or_missing(value)
          value.blank? ? "missing value" : value
        end 

        def array_blank_or_missing(value)
          value.blank? ? ["missing value"] : value
        end 

        def calculate_eligibility_base
          raise "calculate_eligibility_base not implemented"
        end 

        def calculate_eligibility_by_type
          raise "calculate_eligibility_by_type not implemented"
        end 

        def update_eligibility_query
            self.eligibility_query_base = calculate_eligibility_base.to_json
            ELIGIBILITY_TYPES.each do |type|
              self.assign_attributes("eligibility_query_#{type}": calculate_eligibility_by_type(type).to_json)
            end
          end
      
        def eligibility_query(type = 'department')
          eligibility_query_base.json_to_h.merge(self["eligibility_query_#{type}"].json_to_h)
        end 

      end
    end
  end
end

==> hermes-6.0.2.51.tar.gz: hermes-6.0.2.51/app/models/hermes/concerns/eligibility_concern.rb <==
# frozen_string_literal: true

# app/hermes/models/concerns/status.rb
# app/controllers/concerns/test_concern.rb

module Hermes
  module Concerns
    # Handles statuses relationships
    module EligibilityConcern
      extend ActiveSupport::Concern

      included do
        field :eligibility_query_base, type: String
        field :eligibility_query_department, type: String
        field :eligibility_query_seeked, type: String
        field :eligibility_query_bordering, type: String
        field :eligibility_query_seeked_bordering, type: String
        field :eligibility_query_other_from_department, type: String

        def self.eligibility_types
          %w[
            department
            seeked
            bordering
            seeked_bordering
            other_from_department
          ]
        end 

        def blank_or_missing(value)
          value.blank? ? "missing value" : value
        end 

        def array_blank_or_missing(value)
          value.blank? ? ["missing value"] : value
        end 

        def calculate_eligibility_base
          raise "calculate_eligibility_base not implemented"
        end 

        def calculate_eligibility_by_type
          raise "calculate_eligibility_by_type not implemented"
        end 

        def update_eligibility_query
          self.eligibility_query_base = calculate_eligibility_base.to_json
          self.class.eligibility_types.each do |type|
            self.assign_attributes("eligibility_query_#{type}": calculate_eligibility_by_type(type).to_json)
          end
        end
      
        def eligibility_query(type = 'department')
          eligibility_query_base.json_to_h.merge(self["eligibility_query_#{type}"].json_to_h)
        end 

      end
    end
  end
end
